@@ -1,4 +1,5 @@
 import json
+import os
 from typing import Any
 from typing import Dict
 from typing import Optional
@@ -28,6 +29,13 @@ async def dataset_add_resource(
     glob_pattern: Optional[str] = "",
     **kwargs,
 ) -> BaseInterface:
+
+    # Check that path is absolute, which is needed for when the server submits
+    # tasks as a different user
+    if not os.path.isabs(path):
+        msg = f"{path=} is not an absolute path"
+        raise ValueError(msg)
+
     resource = ResourceCreate(path=path, glob_pattern=glob_pattern)
 
     res = await client.post(
